## Version 0.15.2

This release includes important bug fixes to enhance the functionality and reliability of the release notes generation process.

### New Features

- No new features were added in this version.

### Bug Fixes

- Improved the release notes generation to correctly use the newest tag for the filename and ensure accurate commit log ranges. This fix also includes error handling for scenarios where no tags are found, ensuring that the version bump has been executed before generating release notes. (9a248b) (Eric Ma)

### Deprecations

- No deprecations were introduced in this version.
